@@ -77,7 +77,7 @@ func (c *UpgradeCommand) Run(ctx context.Context, originalArgs []string) error {
 
 	fsys := os.DirFS(".")
 
-	files, err := loadYAMLFiles(fsys, args, true)
+	files, err := loadYAMLFiles(fsys, args)
 	if err != nil {
 		return err
 	}
@@ -107,12 +107,11 @@ func (c *UpgradeCommand) Run(ctx context.Context, originalArgs []string) error {
 			outFile = f.path
 		}
 
-		upgraded, err := marshalYAML(f.node)
+		final, err := f.marshalYAML()
 		if err != nil {
 			return fmt.Errorf("failed to marshal yaml for %s: %w", f.path, err)
 		}
 
-		final := removeNewLineChanges(string(f.contents), string(upgraded))
 		if err := atomic.Write(f.path, outFile, strings.NewReader(final)); err != nil {
 			return fmt.Errorf("failed to save file %s: %w", outFile, err)
 		}
